==> omb-skel-1.0.0-4-any.pkg.tar.zst: etc/skel/.config/oh-my-bash/lib/bourne-shell.sh <==
#! bash oh-my-bash.module
# ~/.bashrc: executed by bash(1) for non-login shells.
# see /usr/share/doc/bash/examples/startup-files (in the package bash-doc)

# make less more friendly for non-text input files, see lesspipe(1)
if [ -z "${LESSOPEN}" ];then
  if [ -f /etc/gentoo-release ]; then
    export LESSOPEN="|lesspipe %s"
  else
    if [ -x /usr/bin/lesspipe ]; then
      eval "$(SHELL=/bin/sh /usr/bin/lesspipe)"
    elif [ -x /usr/bin/lesspipe.sh ]; then
      eval "$(SHELL=/bin/sh /usr/bin/lesspipe.sh)"
    fi
  fi
fi

# set variable identifying the chroot you work in (used in the prompt below)
if [ -z "${debian_chroot:-}" ] && [ -r /etc/debian_chroot ]; then
    debian_chroot=$(cat /etc/debian_chroot)
fi

# set a fancy prompt (non-color, unless we know we "want" color)
case "$TERM" in
    xterm-color|*-256color) color_prompt=yes;;
esac

# uncomment for a colored prompt, if the terminal has the capability; turned
# off by default to not distract the user: the focus in a terminal window
# should be on the output of commands, not on the prompt
#force_color_prompt=yes

if [ -n "$force_color_prompt" ]; then
  if [ -x /usr/bin/tput ] && tput setaf 1 >&/dev/null; then
    # We have color support; assume it's compliant with Ecma-48
    # (ISO/IEC-6429). (Lack of such support is extremely rare, and such
    # a case would tend to support setf rather than setaf.)
    color_prompt=yes
  else
    color_prompt=
  fi
fi

if [ "$color_prompt" = yes ]; then
  PS1='${debian_chroot:+($debian_chroot)}\[\033[01;32m\]\u@\h\[\033[00m\]:\[\033[01;34m\]\w\[\033[00m\]\$ '
else
  PS1='${debian_chroot:+($debian_chroot)}\u@\h:\w\$ '
fi
unset color_prompt force_color_prompt

# If this is an xterm set the title to user@host:dir
case "$TERM" in
  xterm*|rxvt*)
    PS1="\[\e]0;${debian_chroot:+($debian_chroot)}\u@\h: \w\a\]$PS1"
    ;;
  *)
    ;;
esac

# enable color support of ls and also add handy aliases
if [ -x /usr/bin/dircolors ]; then
  test -r ~/.dircolors && eval "$(dircolors -b ~/.dircolors)" || eval "$(dircolors -b)"
  #_omb_util_alias ls='dir --color=auto'
  #_omb_util_alias vdir='vdir --color=auto'

  # Note: aliases "grep", "fgrep", and "egrep" are merged in lib/grep.sh
fi

function _omb_util_alias_select_ls {
  if command ls --color=auto ~ &>/dev/null; then
    _omb_command='ls --color=auto'
  elif command ls -G ~ &>/dev/null; then
    _omb_command='ls -G'
  fi
}
_omb_util_alias_delayed ls

# colored GCC warnings and errors
#export GCC_COLORS='error=01;31:warning=01;35:note=01;36:caret=01;32:locus=01:quote=01'

# ls aliases are moved to "lib/directories.sh"

# Add an "alert" alias for long running commands.  Use like so:
#   sleep 10; alert
if _omb_util_binary_exists notify-send; then
  _omb_util_alias alert='notify-send --urgency=low -i "$([ $? = 0 ] && echo terminal || echo error)" "$(history|tail -n1|sed -e '\''s/^\s*[0-9]\+\s*//;s/[;&|]\s*alert$//'\'')"'
fi

# Alias definitions.
# You may want to put all your additions into a separate file like
# ~/.bash_aliases, instead of adding them here directly.
# See /usr/share/doc/bash-doc/examples in the bash-doc package.

if [ -f ~/.bash_aliases ]; then
    . ~/.bash_aliases
fi

if [ -f ~/.bashrc.local ]; then
    . ~/.bashrc.local
fi

# enable programmable completion features (you don't need to enable
# this, if it's already enabled in /etc/bash.bashrc and /etc/profile
# sources /etc/bash.bashrc).
if ! shopt -oq posix; then
  if [ -f /usr/share/bash-completion/bash_completion ]; then
    . /usr/share/bash-completion/bash_completion
  elif [ -f /etc/bash_completion ]; then
    . /etc/bash_completion
  fi
fi

==> omb-skel-1.1.1-1-any.pkg.tar.zst: etc/skel/.config/oh-my-bash/lib/bourne-shell.sh <==
#! bash oh-my-bash.module
# ~/.bashrc: executed by bash(1) for non-login shells.
# see /usr/share/doc/bash/examples/startup-files (in the package bash-doc)

# make less more friendly for non-text input files, see lesspipe(1)
if [[ ! $LESSOPEN ]];then
  if [[ -f /etc/gentoo-release ]]; then
    export LESSOPEN="|lesspipe %s"
  else
    if [[ -x /usr/bin/lesspipe ]]; then
      eval "$(SHELL=/bin/sh /usr/bin/lesspipe)"
    elif [[ -x /usr/bin/lesspipe.sh ]]; then
      eval "$(SHELL=/bin/sh /usr/bin/lesspipe.sh)"
    fi
  fi
fi

# set variable identifying the chroot you work in (used in the prompt below)
if [[ ! ${debian_chroot:-} && -r /etc/debian_chroot ]]; then
  debian_chroot=$(< /etc/debian_chroot)
fi

# set a fancy prompt (non-color, unless we know we "want" color)
case $TERM in
xterm-color|*-256color) color_prompt=yes;;
esac

# uncomment for a colored prompt, if the terminal has the capability; turned
# off by default to not distract the user: the focus in a terminal window
# should be on the output of commands, not on the prompt
#force_color_prompt=yes

if [[ $force_color_prompt ]]; then
  if [[ -x /usr/bin/tput ]] && tput setaf 1 &>/dev/null; then
    # We have color support; assume it's compliant with Ecma-48
    # (ISO/IEC-6429). (Lack of such support is extremely rare, and such
    # a case would tend to support setf rather than setaf.)
    color_prompt=yes
  else
    color_prompt=
  fi
fi

if [[ $color_prompt == yes ]]; then
  PS1='${debian_chroot:+($debian_chroot)}\[\033[01;32m\]\u@\h\[\033[00m\]:\[\033[01;34m\]\w\[\033[00m\]\$ '
else
  PS1='${debian_chroot:+($debian_chroot)}\u@\h:\w\$ '
fi
unset -v color_prompt force_color_prompt

# If this is an xterm set the title to user@host:dir
case $TERM in
xterm*|rxvt*)
  PS1="\[\e]0;${debian_chroot:+($debian_chroot)}\u@\h: \w\a\]$PS1"
  ;;
*)
  ;;
esac

# enable color support of ls and also add handy aliases
if [[ -x /usr/bin/dircolors ]]; then
  if [[ -r ~/.dircolors ]]; then
    eval "$(dircolors -b ~/.dircolors)"
  else
    eval "$(dircolors -b)"
  fi
  #_omb_util_alias ls='dir --color=auto'
  #_omb_util_alias vdir='vdir --color=auto'

  # Note: aliases "grep", "fgrep", and "egrep" are merged in lib/grep.sh
fi

function _omb_util_alias_select_ls {
  if command ls --color=auto ~ &>/dev/null; then
    _omb_command='ls --color=auto'
  elif command ls -G ~ &>/dev/null; then
    _omb_command='ls -G'
  fi
}
_omb_util_alias_delayed ls

# colored GCC warnings and errors
#export GCC_COLORS='error=01;31:warning=01;35:note=01;36:caret=01;32:locus=01:quote=01'

# ls aliases are moved to "lib/directories.sh"

# Add an "alert" alias for long running commands.  Use like so:
#   sleep 10; alert
if _omb_util_binary_exists notify-send; then
  _omb_util_alias alert='notify-send --urgency=low -i "$(if (($? == 0)); then _omb_util_print terminal; else _omb_util_print error; fi)" "$(history|tail -n1|sed -e '\''s/^\s*[0-9]\+\s*//;s/[;&|]\s*alert$//'\'')"'
fi

# Alias definitions.
# You may want to put all your additions into a separate file like
# ~/.bash_aliases, instead of adding them here directly.
# See /usr/share/doc/bash-doc/examples in the bash-doc package.

if [[ -f ~/.bash_aliases ]]; then
  . ~/.bash_aliases
fi

if [[ -f ~/.bashrc.local ]]; then
  . ~/.bashrc.local
fi

# enable programmable completion features (you don't need to enable
# this, if it's already enabled in /etc/bash.bashrc and /etc/profile
# sources /etc/bash.bashrc).
if ! shopt -oq posix; then
  if [[ -f /usr/share/bash-completion/bash_completion ]]; then
    . /usr/share/bash-completion/bash_completion
  elif [[ -f /etc/bash_completion ]]; then
    . /etc/bash_completion
  fi
fi
